==> jbdevstudio-integration-stack-updatesite-8.0.2.CR2.zip: org/teiid/designer/ddl/importer/ui/DdlImporterUiI18n.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * See the LEGAL.txt file distributed with this work for information regarding copyright ownership and licensing.
 *
 * See the AUTHORS.txt file distributed with this work for a full listing of individual contributors.
 */
package org.teiid.designer.ddl.importer.ui;

import static org.teiid.designer.ddl.importer.ui.DdlImporterUiPlugin.i18n;

class DdlImporterUiI18n {
	static final String FILE_GROUP_LABEL = i18n("fileGroupLabel"); //$NON-NLS-1$
    static final String CHOOSE_BUTTON = i18n("chooseButton"); //$NON-NLS-1$
    static final String CHOOSE_DDL_FILE_DIALOG_MSG = i18n("chooseDdlFileDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_DDL_FILE_DIALOG_TITLE = i18n("chooseDdlFileDialogTitle"); //$NON-NLS-1$
    static final String CHOOSE_FROM_FILE_SYSTEM_BUTTON = i18n("chooseFromFileSystemButton"); //$NON-NLS-1$
    static final String CHOOSE_FROM_WORKSPACE_BUTTON = i18n("chooseFromWorkspaceButton"); //$NON-NLS-1$
    static final String DIALECT_LABEL = i18n("dialectLabel"); //$NON-NLS-1$
    static final String AUTO_SELECT_DIALECT_CHECKBOX = i18n("autoSelectDialectCheckBox"); //$NON-NLS-1$
    static final String GENERATE_DEFAULT_SQL_CHECKBOX = i18n("generateDefaultSQLCheckBox"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FOLDER_DIALOG_MSG = i18n("chooseModelFolderDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FOLDER_DIALOG_TITLE = i18n("chooseModelFolderDialogTitle"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FILE_DIALOG_MSG = i18n("chooseModelFileDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FILE_DIALOG_TITLE = i18n("chooseModelFileDialogTitle"); //$NON-NLS-1$
    static final String CONFIRM_DIALOG_TITLE = i18n("confirmDialogTitle"); //$NON-NLS-1$
    static final String CONTINUE_IMPORT_MSG = i18n("continueImportMsg"); //$NON-NLS-1$
    static final String CREATE_MSG_PART = i18n("createMsgPart"); //$NON-NLS-1$
    static final String CREATE_MSG_SUFFIX = i18n("createMsgSuffix"); //$NON-NLS-1$
    static final String DDL_FILE_CONTENTS_TITLE = i18n("ddlFileContentsTitle"); //$NON-NLS-1$
    static final String DDL_FILE_LABEL = i18n("ddlFileLabel"); //$NON-NLS-1$
    static final String DDL_FILE_MSG = i18n("ddlFileMsg"); //$NON-NLS-1$
    static final String IMPORTING_DDL_MSG = i18n("importingDdlMsg"); //$NON-NLS-1$
    static final String MODEL_FOLDER_LABEL = i18n("modelFolderLabel"); //$NON-NLS-1$
    static final String MODEL_FOLDER_MSG = i18n("modelFolderMsg"); //$NON-NLS-1$
    static final String MODEL_MSG = i18n("modelMsg"); //$NON-NLS-1$
    static final String MODEL_NAME_LABEL = i18n("modelNameLabel"); //$NON-NLS-1$
    static final String MODEL_TYPE_LABEL = i18n("modelTypeLabel"); //$NON-NLS-1$
    static final String OPT_TO_CREATE_MODEL_ENTITIES_FOR_UNSUPPORTED_DDL_LABEL = i18n("optToCreateModelEntitiesForUnsupportedDdlLabel"); //$NON-NLS-1$
    static final String OPT_TO_SET_MODEL_ENTITY_DESCRIPTION_LABEL = i18n("optToSetModelEntityDescriptionLabel"); //$NON-NLS-1$
    static final String PAGE_DESCRIPTION = i18n("pageDescription"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DDL_IMPORTED_MSG = i18n("differencePage.noDdlImportedMsg"); //$NON-NLS-1$
    static final String PAGE_TITLE = i18n("pageTitle"); //$NON-NLS-1$
    static final String PATH_MSG_PART = i18n("pathMsgPart"); //$NON-NLS-1$
    static final String PROJECT_MSG_PART = i18n("projectMsgPart"); //$NON-NLS-1$
    static final String UPDATE_MSG_PART = i18n("updateMsgPart"); //$NON-NLS-1$
    static final String WIZARD_TITLE = i18n("wizardTitle"); //$NON-NLS-1$
    static final String IMPORT_COMPLETED_WITH_WARNINGS_TITLE = i18n("importCompletedWithWarningsTitle"); //$NON-NLS-1$
    static final String IMPORT_COMPLETED_WITH_WARNINGS_MESSAGE = i18n("importCompletedWithWarningsMessage"); //$NON-NLS-1$
    static final String MODEL_GROUP_LABEL = i18n("modelGroupLabel"); //$NON-NLS-1$
    static final String OPTIONS_GROUP_LABEL = i18n("optionsGroupLabel"); //$NON-NLS-1$

    static final String DIFFERENCE_PAGE_TITLE = i18n("differencePage.title"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DESCRIPTION = i18n("differencePage.description"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_TREE_GROUP_TITLE = i18n("differencePage.importTreeGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_MESSAGES_GROUP_TITLE = i18n("differencePage.importMessagesGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_DDL_GROUP_TITLE = i18n("differencePage.parseErrorDDLGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_GENERAL_ERROR_TITLE = i18n("differencePage.generalErrorTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_TITLE = i18n("differencePage.parseErrorTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DDLIMPORT_ERROR_MSG = i18n("differencePage.ddlImportErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_MSG = i18n("differencePage.parseErrorMsg"); //$NON-NLS-1$
    
    static final String DIFFERENCE_PAGE_CREATELIST_LABEL = i18n("differencePage.createListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DELETELIST_LABEL = i18n("differencePage.deleteListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_UPDATELIST_LABEL = i18n("differencePage.updateListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_UNKNOWN_LABEL = i18n("differencePage.unknownListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_REPORT_MSG = i18n("differencePage.noDiffReportErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_OPERATIONS_MSG = i18n("differencePage.noDiffOperationsErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_OPERATIONS_SELECTED_MSG = i18n("differencePage.noDiffOperationsSelectedErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_COMPLETED_WITH_MESSAGES_MSG = i18n("differencePage.importCompletedWithMessages"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_SEE_IMPORT_MESSAGES_MSG = i18n("differencePage.seeImportMessagesMsg"); //$NON-NLS-1$
    
    private DdlImporterUiI18n() {
    }
}

==> jbdevstudio-integration-stack-updatesite-8.0.4.CR2.zip: org/teiid/designer/ddl/importer/ui/DdlImporterUiI18n.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * See the LEGAL.txt file distributed with this work for information regarding copyright ownership and licensing.
 *
 * See the AUTHORS.txt file distributed with this work for a full listing of individual contributors.
 */
package org.teiid.designer.ddl.importer.ui;

import static org.teiid.designer.ddl.importer.ui.DdlImporterUiPlugin.i18n;

class DdlImporterUiI18n {
	static final String FILE_GROUP_LABEL = i18n("fileGroupLabel"); //$NON-NLS-1$
    static final String CHOOSE_BUTTON = i18n("chooseButton"); //$NON-NLS-1$
    static final String CHOOSE_DDL_FILE_DIALOG_MSG = i18n("chooseDdlFileDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_DDL_FILE_DIALOG_TITLE = i18n("chooseDdlFileDialogTitle"); //$NON-NLS-1$
    static final String CHOOSE_FROM_FILE_SYSTEM_BUTTON = i18n("chooseFromFileSystemButton"); //$NON-NLS-1$
    static final String CHOOSE_FROM_WORKSPACE_BUTTON = i18n("chooseFromWorkspaceButton"); //$NON-NLS-1$
    static final String DIALECT_LABEL = i18n("dialectLabel"); //$NON-NLS-1$
    static final String AUTO_SELECT_DIALECT_CHECKBOX = i18n("autoSelectDialectCheckBox"); //$NON-NLS-1$
    static final String GENERATE_DEFAULT_SQL_CHECKBOX = i18n("generateDefaultSQLCheckBox"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FOLDER_DIALOG_MSG = i18n("chooseModelFolderDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FOLDER_DIALOG_TITLE = i18n("chooseModelFolderDialogTitle"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FILE_DIALOG_MSG = i18n("chooseModelFileDialogMsg"); //$NON-NLS-1$
    static final String CHOOSE_MODEL_FILE_DIALOG_TITLE = i18n("chooseModelFileDialogTitle"); //$NON-NLS-1$
    static final String CONFIRM_DIALOG_TITLE = i18n("confirmDialogTitle"); //$NON-NLS-1$
    static final String CONTINUE_IMPORT_MSG = i18n("continueImportMsg"); //$NON-NLS-1$
    static final String CREATE_MSG_PART = i18n("createMsgPart"); //$NON-NLS-1$
    static final String CREATE_MSG_SUFFIX = i18n("createMsgSuffix"); //$NON-NLS-1$
    static final String DDL_FILE_CONTENTS_TITLE = i18n("ddlFileContentsTitle"); //$NON-NLS-1$
    static final String DDL_FILE_LABEL = i18n("ddlFileLabel"); //$NON-NLS-1$
    static final String DDL_FILE_MSG = i18n("ddlFileMsg"); //$NON-NLS-1$
    static final String IMPORTING_DDL_MSG = i18n("importingDdlMsg"); //$NON-NLS-1$
    static final String MODEL_FOLDER_LABEL = i18n("modelFolderLabel"); //$NON-NLS-1$
    static final String MODEL_FOLDER_MSG = i18n("modelFolderMsg"); //$NON-NLS-1$
    static final String MODEL_MSG = i18n("modelMsg"); //$NON-NLS-1$
    static final String MODEL_NAME_LABEL = i18n("modelNameLabel"); //$NON-NLS-1$
    static final String MODEL_TYPE_LABEL = i18n("modelTypeLabel"); //$NON-NLS-1$
    static final String OPT_TO_CREATE_MODEL_ENTITIES_FOR_UNSUPPORTED_DDL_LABEL = i18n("optToCreateModelEntitiesForUnsupportedDdlLabel"); //$NON-NLS-1$
    static final String OPT_TO_SET_MODEL_ENTITY_DESCRIPTION_LABEL = i18n("optToSetModelEntityDescriptionLabel"); //$NON-NLS-1$
    static final String FILTER_UCS_FOR_DEFINED_PKS_LABEL = i18n("filterUcsForDefinedPksLabel"); //$NON-NLS-1$
    static final String PAGE_DESCRIPTION = i18n("pageDescription"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DDL_IMPORTED_MSG = i18n("differencePage.noDdlImportedMsg"); //$NON-NLS-1$
    static final String PAGE_TITLE = i18n("pageTitle"); //$NON-NLS-1$
    static final String PATH_MSG_PART = i18n("pathMsgPart"); //$NON-NLS-1$
    static final String PROJECT_MSG_PART = i18n("projectMsgPart"); //$NON-NLS-1$
    static final String UPDATE_MSG_PART = i18n("updateMsgPart"); //$NON-NLS-1$
    static final String WIZARD_TITLE = i18n("wizardTitle"); //$NON-NLS-1$
    static final String IMPORT_COMPLETED_WITH_WARNINGS_TITLE = i18n("importCompletedWithWarningsTitle"); //$NON-NLS-1$
    static final String IMPORT_COMPLETED_WITH_WARNINGS_MESSAGE = i18n("importCompletedWithWarningsMessage"); //$NON-NLS-1$
    static final String MODEL_GROUP_LABEL = i18n("modelGroupLabel"); //$NON-NLS-1$
    static final String OPTIONS_GROUP_LABEL = i18n("optionsGroupLabel"); //$NON-NLS-1$

    static final String DIFFERENCE_PAGE_TITLE = i18n("differencePage.title"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DESCRIPTION = i18n("differencePage.description"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_TREE_GROUP_TITLE = i18n("differencePage.importTreeGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_MESSAGES_GROUP_TITLE = i18n("differencePage.importMessagesGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_DDL_GROUP_TITLE = i18n("differencePage.parseErrorDDLGroupTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_GENERAL_ERROR_TITLE = i18n("differencePage.generalErrorTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_TITLE = i18n("differencePage.parseErrorTitle"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DDLIMPORT_ERROR_MSG = i18n("differencePage.ddlImportErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_PARSE_ERROR_MSG = i18n("differencePage.parseErrorMsg"); //$NON-NLS-1$
    
    static final String DIFFERENCE_PAGE_CREATELIST_LABEL = i18n("differencePage.createListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_DELETELIST_LABEL = i18n("differencePage.deleteListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_UPDATELIST_LABEL = i18n("differencePage.updateListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_UNKNOWN_LABEL = i18n("differencePage.unknownListLabel"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_REPORT_MSG = i18n("differencePage.noDiffReportErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_OPERATIONS_MSG = i18n("differencePage.noDiffOperationsErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_NO_DIFFERENCE_OPERATIONS_SELECTED_MSG = i18n("differencePage.noDiffOperationsSelectedErrorMsg"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_IMPORT_COMPLETED_WITH_MESSAGES_MSG = i18n("differencePage.importCompletedWithMessages"); //$NON-NLS-1$
    static final String DIFFERENCE_PAGE_SEE_IMPORT_MESSAGES_MSG = i18n("differencePage.seeImportMessagesMsg"); //$NON-NLS-1$
    
    private DdlImporterUiI18n() {
    }
}
